#!/usr/bin/env python3
"""demo-show.py : demonstration of scripting action across all theater units
"""
import argparse, time, logging
import numpy as np

from pythonosc import osc_message_builder
from pythonosc import udp_client

import theater.config
import theater.network

# import common logging functions
import theater.logging

# initialize logging for this module
log = logging.getLogger('demo')

#================================================================
if __name__ == "__main__":

    # set up logging
    theater.logging.open_log_file('logs/demo-show.log')
    log.info("Starting demo-show.py")

    parser = argparse.ArgumentParser( description = "Simple scripted show.")
    parser.add_argument("--ip", default=theater.config.theater_IP,  help="IP address of the OSC receiver (default: %(default)s).")
    theater.logging.add_logging_args(parser)
    args = parser.parse_args()

    # Modify logging settings as per common arguments.
    theater.logging.configure_logging(args)

    # create OSC clients to send messages to the theater system
    network = theater.network.TheaterNetwork(args)

    # turn on each RGBA fixture
    for fixture in ['rgba1', 'rgba2']:
        network.lights.send_message("/fixture", [fixture, 255, 255, 255, 255])
        log.debug("Lighting fixture %s", fixture)
        time.sleep(2)
        network.lights.send_message("/fixture", [fixture, 0, 0, 0, 0])

    # activate each motor axis in turn along with the associated light fixture
    for unit, m in enumerate(network.motion):
        fixture = ['blue', 'magenta', 'straw', 'white'][unit]
        network.lights.send_message("/fixture", [fixture, 255])

        for axis in range(4):
            m.send_message("/spline", [axis, 0.0, 90.0, 90.0])
            log.debug("Moving unit %d axis %d", unit, axis)
            time.sleep(1)

        network.lights.send_message("/fixture", [fixture, 0])

    # next activate each mono light in turn
    for c in range(8):
        network.lights.send_message("/fixture", [c, 255])
        log.debug("Lighting fixture %d", c)
        time.sleep(1)

        network.lights.send_message("/fixture", [c, 0])
        time.sleep(1)

    # next activate each RGBA fixture in turn
    for fixture in ['rgba1', 'rgba2']:
        network.lights.send_message("/fixture", [fixture, 255, 255, 255, 255])
        log.debug("Lighting fixture %s", fixture)
        time.sleep(1)
        network.lights.send_message("/fixture", [fixture, 0, 0, 0, 0])
        time.sleep(1)

    log.info("Exiting demo-show.py")
