"""network.py

OSC UDP messaging network support common to several scripts."""

import logging

from pythonosc import osc_message_builder
from pythonosc import udp_client

# UDP port numbers for servers
from .config import lighting_UDP_port, motor_UDP_port, director_UDP_port, motor_units

# initialize logging for this module
log = logging.getLogger('network')

#================================================================
class TheaterNetwork:
    """Manage the UDP sockets for sending data to the theater system."""

    def __init__(self, args):

        # Create the motion networking outputs.  These creates a separate socket for each motion server output for simplicity.
        self.motion = []
        for unit in range(motor_units):
            self.motion.append(udp_client.SimpleUDPClient(args.ip, motor_UDP_port + unit))
            log.info("Opened motion client socket to send to %s:%d", args.ip, motor_UDP_port + unit)

        # Create a socket to communicate to the lighting server.
        self.lights = udp_client.SimpleUDPClient(args.ip, lighting_UDP_port)
        log.info("Opened lighting client socket to send to %s:%d", args.ip, lighting_UDP_port)

        # Create a socket to communicate to the central controller.
        self.director = udp_client.SimpleUDPClient(args.ip, director_UDP_port)
        log.info("Opened director client socket to send to %s:%d", args.ip, director_UDP_port)
        return

    def close(self):
        pass

    def num_motion_units(self):
        return len(self.motion)

    def motion_server(self, unit):
        return self.motion[unit]

    def lighting_server(self, unit=0):
        return self.lights

#================================================================
